Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4562)

Unified Diff: ash/common/system/chromeos/network/vpn_list_view.h

Issue 2510083006: chromeos: Move ownership of ash VPN provider list from chrome into ash (Closed)
Patch Set: Collapse VPNProvider::Key and VPNProvider structs Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/system/chromeos/network/vpn_list_view.h
diff --git a/ash/common/system/chromeos/network/vpn_list_view.h b/ash/common/system/chromeos/network/vpn_list_view.h
index 01cfdf4579fd54e1e899af948b4c237fb2a18db4..205b9687737fa075aa4cd25c062aa94898fd644c 100644
--- a/ash/common/system/chromeos/network/vpn_list_view.h
+++ b/ash/common/system/chromeos/network/vpn_list_view.h
@@ -63,11 +63,10 @@ class VPNListView : public NetworkListViewBase,
// Adds a network to the list.
void AddNetwork(const chromeos::NetworkState* network);
// Adds the VPN provider identified by |key| to the list, along with any
// networks that belong to this provider.
void AddProviderAndNetworks(
- const VPNProvider::Key& key,
- const std::string& name,
+ const VPNProvider& vpn_provider,
const chromeos::NetworkStateHandler::NetworkStateList& networks);
// Adds all available VPN providers and networks to the list.
@@ -76,8 +75,8 @@ class VPNListView : public NetworkListViewBase,
NetworkListDelegate* const delegate_;
- // A mapping from each VPN provider's list entry to the provider's key.
- std::map<const views::View* const, VPNProvider::Key> provider_view_key_map_;
+ // A mapping from each VPN provider's list entry to the provider.
+ std::map<const views::View* const, VPNProvider> provider_view_map_;
// A mapping from each network's list entry to the network's service path.
std::map<const views::View* const, std::string>
@@ -63,11 +63,10 @@ class VPNListView : public NetworkListViewBase,
// Adds a network to the list.
void AddNetwork(const chromeos::NetworkState* network);
- // Adds the VPN provider identified by |key| to the list, along with any
- // networks that belong to this provider.
+ // Adds the VPN provider identified by |vpn_provider| to the list, along with
+ // any networks that belong to this provider.
void AddProviderAndNetworks(

Powered by Google App Engine
This is Rietveld 408576698